##  Making a Question Mandatory
You can make a question mandatory by toggling the Mandatory switch on at the top right of the question. When a question is mandatory, respondents must answer it before submitting the survey. This ensures that critical information or key insights are collected from all participants, maintaining the integrity and completeness of the data, which is vital to the survey's objectives.
![Making a Question Mandatory](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2746f0ea7a44101496e9e984409614a0_LowRes.png)
Making a Question Mandatory
